@@ -223,18 +223,24 @@ const char* doc_copy_from_csv =
 
 static PyObject* Connection_copy_from_csv(PyObject* self, PyObject* args, PyObject* kwargs)
 {
-    static const char *kwlist[] = { "table", "source", "header", 0 };
+    static const char *kwlist[] = { "table", "source", "header", "delimiter", "quote", 0 };
 
     PyObject* table;
     PyObject* source;
     int header = 0;
-    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "UO|p", (char**)kwlist, &table, &source, &header))
+    char* szDelimiter = 0;
+    char* szQuote = 0;
+    if (!PyArg_ParseTupleAndKeywords(args, kwargs, "UO|pzz", (char**)kwlist, &table, &source, &header, &szDelimiter, &szQuote))
         return 0;
 
     char header_token[] = "header";
     if (header == 0)
         header_token[0] = 0;
-    PyObject* sql = PyUnicode_FromFormat("copy %U from stdin with csv %s", table, header_token);
+
+    const char* pszDelimiter = szDelimiter ? szDelimiter : ",";
+    const char* pszQuote = szQuote ? szQuote : "\"";
+    PyObject* sql = PyUnicode_FromFormat("copy %U from stdin with csv %s delimiter '%s' quote '%s'",
+                                         table, header_token, pszDelimiter, pszQuote);
 
     // If source is a string (Unicode), store the UTF-encoded value in buffer. If a byte
     // object, store directly in buffer.  Otherwise, buffer will be zero and `source` must be
