@@ -9,7 +9,10 @@
 #include "params.h"
 #include "errors.h"
 #include "enums.h"
-#include "custom_types.h"
+#include "type_hstore.h"
+#include "type_json.h"
+#include "type_ltree.h"
+#include "conninfoopt.h"
 
 PyObject* pModule = 0;
 PyObject* Error;
@@ -22,40 +25,6 @@ PyObject* strEmpty;
 
 static char module_doc[] = "A straightforward library for PostgreSQL";
 
-static char doc_defaults[] = "Returns the dictionary of default conninfo values.";
-
-
-static PyObject* mod_defaults(PyObject* self, PyObject* args)
-{
-    UNUSED(self);
-
-    Object dict(PyDict_New());
-    if (!dict)
-        return 0;
-
-    PQconninfoOption* aOptions = PQconndefaults();
-    PQconninfoOption* p = aOptions;
-    while (p->keyword)
-    {
-        if (p->val == NULL)
-        {
-            if (PyDict_SetItemString(dict, p->keyword, Py_None) == -1)
-                return 0;
-        }
-        else
-        {
-            Object val(PyUnicode_FromString(p->val ? p->val : "NULL"));
-            if (!val || PyDict_SetItemString(dict, p->keyword, val) == -1)
-                return 0;
-        }
-        p++;
-    }
-
-    PQconninfoFree(aOptions);
-
-    return dict.Detach();
-}
-
 static char connect_doc[] =
 "connect(connection_string) --> Connection";
 
@@ -153,13 +122,30 @@ static PyObject* mod_register_type(PyObject* self, PyObject* args)
         Py_RETURN_NONE;
     }
 
-    return SetStringError(PyExc_ValueError, "register_type only supports 'hstore' at this time");
+    if (PyOS_stricmp(szTypeName, "ltree") == 0)
+    {
+        RegisterLTree(oid);
+        Py_RETURN_NONE;
+    }
+
+    return SetStringError(PyExc_ValueError, "register_type only supports 'hstore' and 'ltree' at this time");
 }
 
 
 static PyObject* mod_connection_count()
 {
-    return PyLong_FromLong(GetConnectionCount());
+  return PyLong_FromLong(GetConnectionCount());
+}
+
+
+static char doc_defaults[] = "Returns the dictionary of default conninfo values.";
+
+static PyObject* mod_defaults() {
+    ConnInfo info(PQconndefaults());
+    if (!info) {
+        return PyErr_NoMemory();
+    }
+    return DictFromConnInfo(info);
 }
 
 // static PyObject* mod_test(PyObject* self, PyObject* args)
@@ -236,7 +222,8 @@ PyMODINIT_FUNC PyInit__pglib()
     }
 
     if (PyType_Ready(&ConnectionType) < 0 || PyType_Ready(&ResultSetType) < 0
-        || PyType_Ready(&RowType) < 0 || PyType_Ready(&HstoreType) < 0)
+        || PyType_Ready(&RowType) < 0 || PyType_Ready(&HstoreType) < 0
+        || PyType_Ready(&JsonType) < 0)
     {
         return 0;
     }
@@ -279,5 +266,8 @@ PyMODINIT_FUNC PyInit__pglib()
     PyModule_AddObject(module, "hstore", (PyObject*)&HstoreType);
     Py_INCREF((PyObject*)&HstoreType);
 
+    PyModule_AddObject(module, "json", (PyObject*)&JsonType);
+    Py_INCREF((PyObject*)&JsonType);
+
     return module.Detach();
 }
