@@ -214,6 +214,26 @@ def test_copy_csv_string_cols(cnxn):
     assert row.b == 'two'
 
 
+def test_copy_psv_string(cnxn):
+    cnxn.execute("create table t1(a int, b varchar(20))")
+    count = cnxn.copy_from_csv("t1", '1|"one"\n2|"two"', delimiter='|')
+    assert count == 2
+    row = cnxn.fetchrow("select a,b from t1 where a=2")
+    assert row.a == 2
+    assert row.b == 'two'
+
+def test_copy_psv_quote(cnxn):
+    # Send in some data with a quote in it as part of the string like 1/2".  We'll change the
+    # quotes to something not in the data (a bel/7 character) and ensure it considered the quote
+    # as part of the data.
+
+    cnxn.execute("create table t1(a int, b varchar(20))")
+    count = cnxn.copy_from_csv("t1", '1|1/2"\n2|3/4"', delimiter='|', quote="\x07")
+    assert count == 2
+    row = cnxn.fetchrow("select a,b from t1 where a=2")
+    assert row.a == 2
+    assert row.b == '3/4"'
+
 #
 # row
 #
